@@ -21,7 +21,7 @@ corresponding to a database session id) is stored in the cookie.
   >>> from paste.httpserver import serve
   >>> from paste.fileapp import DataApp
   >>> from paste.httpexceptions import *
-  >>> # from paste.auth.cookie import AuthCookiehandler
+  >>> from paste.auth.cookie import AuthCookieHandler
   >>> from paste.wsgilib import parse_querystring
   >>> def testapp(environ, start_response):
   ...     user = dict(parse_querystring(environ)).get('user','')
@@ -41,12 +41,18 @@ corresponding to a database session id) is stored in the cookie.
 
 """
 
-import sha, hmac, base64, random, time, warnings
+import hmac, base64, random, time, warnings
+try:
+    from hashlib import sha1
+except ImportError:
+    # NOTE: We have to use the callable with hashlib (hashlib.sha1),
+    # otherwise hmac only accepts the sha module object itself
+    import sha as sha1
 from paste.request import get_cookies
 
 def make_time(value):
     return time.strftime("%Y%m%d%H%M", time.gmtime(value))
-_signature_size = len(hmac.new('x', 'x', sha).digest())
+_signature_size = len(hmac.new('x', 'x', sha1).digest())
 _header_size = _signature_size + len(make_time(time.time()))
 
 # @@: Should this be using urllib.quote?
@@ -70,7 +76,7 @@ def new_secret():
     """ returns a 64 byte secret """
     return ''.join(random.sample(_all_chars, 64))
 
-class AuthCookieSigner:
+class AuthCookieSigner(object):
     """
     save/restore ``environ`` entries via digially signed cookie
 
@@ -131,10 +137,11 @@ class AuthCookieSigner:
         need to be escaped and quoted).  The expiration of this
         cookie is handled server-side in the auth() function.
         """
-        cookie = base64.b64encode(
-            hmac.new(self.secret, content, sha).digest() +
+        cookie = base64.encodestring(
+            hmac.new(self.secret, content, sha1).digest() +
             make_time(time.time() + 60*self.timeout) +
-            content).replace("/", "_").replace("=", "~")
+            content)[:-1]
+        cookie = cookie.replace("/", "_").replace("=", "~")
         if len(cookie) > self.maxlen:
             raise CookieTooLarge(content, cookie)
         return cookie
@@ -144,12 +151,12 @@ class AuthCookieSigner:
         Authenticate the cooke using the signature, verify that it
         has not expired; and return the cookie's content
         """
-        decode = base64.b64decode(
+        decode = base64.decodestring(
             cookie.replace("_", "/").replace("~", "="))
         signature = decode[:_signature_size]
         expires = decode[_signature_size:_header_size]
         content = decode[_header_size:]
-        if signature == hmac.new(self.secret, content, sha).digest():
+        if signature == hmac.new(self.secret, content, sha1).digest():
             if int(expires) > int(make_time(time.time())):
                 return content
             else:
@@ -180,7 +187,7 @@ class AuthCookieEnviron(list):
             return
         list.append(self, str(value))
 
-class AuthCookieHandler:
+class AuthCookieHandler(object):
     """
     the actual handler that should be put in your middleware stack
 
