@@ -68,12 +68,12 @@ class HeaderDict(dict):
 
     def headeritems(self):
         result = []
-        for key in self:
-            if isinstance(self[key], list):
-                for v in self[key]:
+        for key, value in self.items():
+            if isinstance(value, list):
+                for v in value:
                     result.append((key, str(v)))
             else:
-                result.append((key, str(self[key])))
+                result.append((key, str(value)))
         return result
 
     #@classmethod
@@ -197,7 +197,7 @@ def error_response(environ, error_code, message,
 
     Use like:
     
-    .. code-block:: Python
+    .. code-block:: python
 
         status, headers, body = wsgilib.error_response(
             '301 Moved Permanently', 'Moved to <a href="%s">%s</a>'
